![Documentation](https://github.com/krishols/designer/actions/workflows/docs.yml/badge.svg)
# Designer
An interactive graphics library designed with student data to learn Python.

# Installation
Install from the command line: 

 ```
 pip install designer
 ```
  
Or install from [this repository](https://github.com/krishols/designer).

# Documentation
Find the documentation for Designer [here](https://krishols.github.io/designer/).
